[![Build Status](https://travis-ci.com/ICB-DCM/PEtab.svg?branch=master)](https://travis-ci.com/ICB-DCM/PEtab)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/c1e34bb9ade14fe6bce54199be18535c)](https://www.codacy.com/app/dweindl/PEtab?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=ICB-DCM/PEtab&amp;utm_campaign=Badge_Grade)
[![codecov](https://codecov.io/gh/ICB-DCM/PEtab/branch/master/graph/badge.svg)](https://codecov.io/gh/ICB-DCM/PEtab)
[![PyPI version](https://badge.fury.io/py/petab.svg)](https://badge.fury.io/py/petab)


# PEtab --- a data format for specifying parameter estimation problems in system biology

This repository describes *PEtab* --- a data format for specifying parameter estimation problems in system biology, provides a Python library for easy access and validation of *PEtab* files. See [doc/documentation_data_format.md](doc/documentation_data_format.md) for more info.

Where PEtab is used:

- Systems biology optimization [benchmark problem collection](https://github.com/LoosC/Benchmark-Models/issues)
- [pyPESTO](https://github.com/ICB-DCM/pyPESTO/)
